import { Module } from "@nestjs/common";

import { AskarDynamicModule } from "@ocm-engine/askar";
import { ConfigModule } from "@nestjs/config";
import {
  agentConfig,
  agentSchema,
  authSchema,
  gatewayConfig,
  gatewaySchema,
  ledgersConfig,
  ledgersSchema,
  natsConfig,
  natsSchema,
} from "@ocm-engine/config";
import Joi from "joi";

const validationSchema = Joi.object({
  agent: agentSchema,
  auth: authSchema,
  ledgers: ledgersSchema,
  nats: natsSchema,
  gateway: gatewaySchema,
});

@Module({
  imports: [
    AskarDynamicModule.forRootAsync(),
    ConfigModule.forRoot({
      isGlobal: true,
      load: [agentConfig, ledgersConfig, natsConfig, gatewayConfig],
      validationSchema,
    }),
  ],
  controllers: [],
  providers: [],
})
export class AppModule {}
