import React, { useEffect, useState } from "react";
import { ToastContainer } from "react-toastify";
import PageRoutes from "@dashboard/routes";
import modalStore from "@dashboard/store/modalStore";
import { observer } from "mobx-react";
import useGlobalAuth from "@dashboard/hooks/useGlobalAuth";
import { setConfig as setOcmEngineConfig } from "@dashboard/engine-api";
import getConfig from "@dashboard/utils/getConfig";
import s from "./styles.module.scss";

const App = observer(() => {
  const auth = useGlobalAuth();
  const [isAppLoading, setAppLoading] = useState(true);

  useEffect(() => {
    const config = getConfig();
    setOcmEngineConfig({
      onUnauthorized: () => {
        auth.setToken(null);
      },
      wsUrl: config.OCMENGINE_WS_URL,
      httpUrl: config.OCMENGINE_HTTP_URL,
      getToken: async () => auth.getToken() || "",
    });
    setAppLoading(false);
  }, [auth]);

  let content;
  if (isAppLoading) {
    content = (
      <div className={s.loader}>
        <img
          className={s.loaderLogo}
          alt="vereign"
          src="https://www.vereign.com/vereign-logo.svg"
        />
      </div>
    );
  } else {
    content = <PageRoutes />;
  }
  return (
    <div className={s.root}>
      {content}
      <ToastContainer />
      {modalStore.modals.map((p) => (
        <React.Fragment key={p.id}>{p.modal as React.ReactNode}</React.Fragment>
      ))}
    </div>
  );
});

export default App;
