import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Spin } from "antd";
import ProofListStore from "./ProofListStore";
import NoRecordsMessage from "../NoRecordsMessage";
import ProofItem from "@dashboard/components/ProofItem";
import modalStore from "@dashboard/store/modalStore";

export interface ProofListProps {
  connectionId: string | null;
}

const ProofList: React.FC<ProofListProps> = observer(({ connectionId }) => {
  const [store] = useState(() => new ProofListStore());

  useEffect(() => {
    store.loadAll(connectionId);
  }, [store, connectionId]);

  const handleDelete = async (proofId: string) => {
    modalStore.openConfirmDialog({
      title: "Are you sure to delete this proof request?",
      description: "",
      dangerOk: true,
      onOk: async (e) => {
        await store.remove(proofId);
        e.close();
      },
    });
  };

  const handleDecline = async (proofId: string) => {
    modalStore.openConfirmDialog({
      title: "Are you sure you want to decline this proof request?",
      description: "",
      dangerOk: true,
      onOk: async (e) => {
        await store.decline(proofId);
        e.close();
      },
    });
  };

  return (
    <div>
      {store.items.map((p) => (
        <ProofItem
          key={p.id}
          item={p}
          onAccept={() => store.accept(p.id!)}
          onDecline={() => handleDecline(p.id!)}
          statusChanging={store.statusChangeId === p.id}
          onRemove={() => handleDelete(p.id!)}
        />
      ))}
      {!store.loading && !store.items.length && <NoRecordsMessage />}
      {store.loading && <Spin />}
    </div>
  );
});

export default ProofList;
