import * as ReactDOM from "react-dom/client";
import { BrowserRouter } from "react-router-dom";
import { ConfigProvider } from "antd";
import getConfig from "./utils/getConfig";
import App from "./components/App";

import ocmApi, { setConfig as setOcmEngineConfig } from "@dashboard/engine-api";
import tsaApi, { setConfig as setTsaConfig } from "@dashboard/tsa-api";
import { AuthProvider } from "@dashboard/hooks/auth/Provider";

import "normalize.css";
import "react-toastify/dist/ReactToastify.css";
import "@fontsource/roboto";
import "@fontsource/roboto/500.css";
import "@fontsource/roboto/700.css";

const config = getConfig();

setOcmEngineConfig({
  wsUrl: config.OCMENGINE_WS_URL,
  httpUrl: config.OCMENGINE_HTTP_URL,
  getToken: async () => "",
});

setTsaConfig({
  tsaUrl: config.TSA_URL,
});

ocmApi.initialize();
tsaApi.initialize();

const root = ReactDOM.createRoot(
  document.getElementById("root") as HTMLElement,
);
root.render(
  <BrowserRouter basename={window.BASE_PATH}>
    <ConfigProvider
      theme={{
        token: {
          colorPrimary: "#06b4cb",
          fontFamily: "Roboto",
        },
      }}
    >
      <AuthProvider>
        <App />
      </AuthProvider>
    </ConfigProvider>
  </BrowserRouter>,
);
