import React, { useEffect } from "react";
import { observer } from "mobx-react";
import Modal, { FcProps } from "@dashboard/components/Modal";
import { ProofRecordDto } from "@dashboard/engine-api";
import ProofItem from "@dashboard/components/ProofItem";
import { QRCode } from "antd";
import s from "./styles.module.scss";

export interface ViewConnectionlessProofRequestProps {
  proofUrl: string | undefined | null;
  proofUrlShort: string | undefined | null;
  proofRecord: ProofRecordDto;
}

const ViewConnectionlessProofRequest = observer(
  ({
    setTitle,
    setWidth,
    setClassName,
    onClose,
    data,
  }: FcProps<ViewConnectionlessProofRequestProps>) => {
    useEffect(() => {
      setClassName(s.modal);
      setWidth("80vw");
      setTitle("Connectionless proof request");
    }, [setClassName, setWidth, setTitle]);

    return (
      <Modal.Body className={s.body}>
        <div className={s.info}>
          <div>
            <div className={s.qrCodeHint}>
              Scan this QR code with mobile wallet
            </div>
            <div className={s.qrWrapper}>
              {data.proofUrlShort && (
                <QRCode value={data.proofUrlShort} size={500} />
              )}
            </div>
            <div>
              <div className={s.urlTitle}>Proof request URL:</div>
              <div className={s.url}>
                <b>{data.proofUrl}</b>
              </div>
              <div className={s.urlTitle}>Proof request short URL:</div>
              <div className={s.url}>
                <b>{data.proofUrlShort}</b>
              </div>
              {data.proofRecord && (
                <div>
                  Details:
                  <ProofItem item={data.proofRecord} />
                </div>
              )}
            </div>
          </div>
        </div>
      </Modal.Body>
    );
  },
);

export default ViewConnectionlessProofRequest;
