import { makeAutoObservable, runInAction } from "mobx";
import api, { ConnectionRecordDto } from "@dashboard/engine-api";
import displayError from "@dashboard/utils/displayError";

class ConnectionListStore {
  public loading = false;
  public list: ConnectionRecordDto[] = [];
  public searchQuery = "";
  public get filteredList() {
    const query = this.searchQuery.trim().toLowerCase();
    if (query) {
      return this.list.filter(
        (p) =>
          (p.connectionName &&
            p.connectionName.toLowerCase().indexOf(query) >= 0) ||
          (p.id && p.id.indexOf(query) >= 0) ||
          (p.alias && p.alias.toLowerCase().indexOf(query) >= 0) ||
          (p.did && p.did.indexOf(query) >= 0) ||
          (p.outOfBandId && p.outOfBandId.indexOf(query) >= 0),
      );
    }
    return this.list;
  }

  constructor() {
    makeAutoObservable(this);
  }

  public async getAll() {
    runInAction(() => (this.loading = true));
    try {
      const list = await api.fetchConnections();
      runInAction(() => {
        this.list = list;
        this.loading = false;
      });
    } catch (e: unknown) {
      displayError(e);
      runInAction(() => (this.loading = false));
    }
  }
}

export type { ConnectionListStore };

export default ConnectionListStore;
