import React, { useState, useEffect } from "react";
import { observer } from "mobx-react";
import CredentialList from "@dashboard/components/CredentialList";
import PageWithSidebar from "@dashboard/components/PageWithSidebar";
import PageTitle from "@dashboard/components/PageTitle";
import { Button, Space } from "antd";
import modalStore from "@dashboard/store/modalStore";
import CredentialListStore from "@dashboard/components/CredentialList/CredentialListStore";

const CredentialListPage = observer(() => {
  const [store] = useState(() => new CredentialListStore());

  useEffect(() => {
    store.loadAll(null);
  }, [store]);

  return (
    <PageWithSidebar>
      <h2>Actions</h2>
      <Space direction="horizontal">
        <Button
          onClick={() => {
            modalStore.openOfferCredentialDialog({
              connectionId: undefined,
              onCredentialOffered: (offer) => {
                modalStore.openViewConnectionlessCredentialOffer({
                  credentialUrl: offer.credentialUrl,
                  credentialUrlShort: offer.shortCredentialUrl,
                  credentialRecord: offer.credentialRecord,
                });
              },
            });
          }}
        >
          Offer connectionless credential
        </Button>
        <Button
          onClick={() => {
            modalStore.openOfferJsonLdCredentialDialog({
              connectionId: undefined,
              onCredentialOffered: (offer) => {
                modalStore.openViewConnectionlessCredentialOffer({
                  credentialUrl: offer.credentialUrl,
                  credentialUrlShort: offer.shortCredentialUrl,
                  credentialRecord: offer.credentialRecord,
                });
              },
            });
          }}
        >
          Offer connectionless JSON-LD credential
        </Button>
        <Button
          onClick={() => {
            modalStore.openAcceptConnectionlessCredentialOfferDialog({
              onCredentialReceived: (credentialRecord) => {
                modalStore.openViewJsonDialog({ data: credentialRecord });
              },
            });
          }}
        >
          Accept connectionless credential
        </Button>
      </Space>
      <PageTitle>Credentials</PageTitle>
      <div>
        <CredentialList connectionId={null} />
      </div>
    </PageWithSidebar>
  );
});

export default CredentialListPage;
