import { makeAutoObservable, runInAction } from "mobx";
import api, { SchemaRecordDto } from "@dashboard/engine-api";
import displayError from "@dashboard/utils/displayError";

class VcmSelfIssuePageStore {
  public loading = false;
  public schemas: SchemaRecordDto[] = [];
  public selectedSchemaId: string | null = null;
  public schemaUrl = "";

  constructor() {
    makeAutoObservable(this);
  }

  public async initialize() {
    runInAction(() => (this.loading = true));
    try {
      const schemas = await api.fetchSchemas();

      runInAction(() => {
        this.schemas = schemas;
        this.loading = false;
      });
    } catch (e: unknown) {
      displayError(e);
      runInAction(() => (this.loading = false));
    }
  }
}

export type { VcmSelfIssuePageStore };

export default VcmSelfIssuePageStore;
