import {
  Injectable,
  InternalServerErrorException,
  Logger,
} from "@nestjs/common";
import {
  ClientProxy,
  ClientProxyFactory,
  Transport,
} from "@nestjs/microservices";
import { ConfigService } from "@nestjs/config";
import { IAttestationManagerConfig } from "@ocm-engine/config";
import {
  GatewayAcceptedResponseDto,
  CredentialEvent,
  SchemaEvent,
  BasicMessageEvent,
} from "@ocm-engine/dtos";
import { lastValueFrom } from "rxjs";

@Injectable()
export class AttestationManagerClient {
  private client: ClientProxy;
  private amConfig: IAttestationManagerConfig;
  private readonly logger: Logger = new Logger(AttestationManagerClient.name);

  constructor(configService: ConfigService) {
    this.amConfig = configService.get<IAttestationManagerConfig>("am")!;

    this.client = ClientProxyFactory.create({
      transport: Transport.TCP,
      options: {
        host: this.amConfig.host,
        port: this.amConfig.port,
      },
    });
  }

  async sendPayload<T>({
    pattern,
    payload,
  }: {
    pattern: string;
    payload: {
      data: T;
      type: SchemaEvent | CredentialEvent | BasicMessageEvent;
      source: string;
    };
  }): Promise<GatewayAcceptedResponseDto> {
    this.logger.debug(
      `sending payload to attestation manager ${JSON.stringify(
        payload,
        null,
        2,
      )}`,
    );

    return lastValueFrom(this.client.send(pattern, payload)).catch((e) => {
      throw new InternalServerErrorException(e.message);
    });
  }
}
